<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>AboutForm</name>
    <message>
        <location filename="../ui/aboutform.ui" line="14"/>
        <source>About SomePlayer</source>
        <translation>Sobre SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="120"/>
        <source>&lt;b&gt;SomePlayer&lt;/b&gt; </source>
        <translation>&lt;b&gt;SomePlayer&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="130"/>
        <source>&gt;&lt;</source>
        <translation>&gt;&lt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="165"/>
        <source>&lt;p align=&quot;center&quot;&gt;Alternative music player for Maemo 5. It includes media-library, playlists, equalizer, and supports many other things.&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;Tocador de músicas alternativo para Maemo 5. Inclui biblioteca de mídias, playlists, equalizador, e suporta muitas outras funcionalidades.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="188"/>
        <source>&lt;p align=&quot;center&quot;&gt;Licensed under GPLv2&lt;br&gt;
By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b&gt;SomePlayer&lt;/b&gt; tries to be a full replacement of standard music player for Maemo5 with many other features such as equalizer, custom playlists, smarter random mode, more flexible media-library and improved algorithm for cover searching.&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;Licenciado sob GPLv2&lt;br&gt;
Por Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b&gt;SomePlayer&lt;/b&gt; tenta substituir completamente o tocador de músicas padrão do Maemo 5, trazendo várias novas funcionalidades, como equalizador, playlist personalizadas, modo aleatório inteligente, biblioteca de mídias mais flexível e um algoritmo de busca de capas de discos melhorado.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="212"/>
        <source>&lt;p align=&quot;center&quot;&gt;
&lt;b&gt;Thanks to:&lt;/b&gt;&lt;br&gt;
MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemoworld.ru)&lt;br /&gt;lknfox (maemoworld.ru)&lt;br /&gt;fab (maemoworld.ru)&lt;br /&gt;Pantera1989m (github.com)&lt;br /&gt;willkr (maemo.org)&lt;br /&gt;and other people who tested this player and helped in development&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;
&lt;b&gt;Agradecimentos:&lt;/b&gt;&lt;br&gt;
MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemoworld.ru)&lt;br /&gt;lknfox (maemoworld.ru)&lt;br /&gt;fab (maemoworld.ru)&lt;br /&gt;Pantera1989m (github.com)&lt;br /&gt;willkr (maemo.org)&lt;br /&gt;e todas as pessoas que testaram e ajudaram no desenvolvimento deste software&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="226"/>
        <source>Online help</source>
        <translation>Ajuda Online</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="233"/>
        <source>Donate</source>
        <translation>Concluído</translation>
    </message>
</context>
<context>
    <name>AddStreamingMediaDialog</name>
    <message>
        <location filename="../ui/addstreamingmediadialog.ui" line="14"/>
        <source>Add audio stream</source>
        <translation>Adicionar fluxo de áudio</translation>
    </message>
    <message>
        <location filename="../ui/addstreamingmediadialog.ui" line="27"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../ui/addstreamingmediadialog.ui" line="34"/>
        <source>Name</source>
        <translatorcomment>Nome</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>DirectoryView</name>
    <message>
        <location filename="../ui/directoryview.ui" line="14"/>
        <source>Directories</source>
        <translation>Diretórios</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="91"/>
        <source>Audioclips</source>
        <translation>Clipes de áudio</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="327"/>
        <source>Internal memory</source>
        <translation>Memória interna</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="329"/>
        <source>Memory card</source>
        <translation>Cartão de memória</translation>
    </message>
</context>
<context>
    <name>EditTagsDialog</name>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="14"/>
        <source>Edit tags</source>
        <translation>Editar tags</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="22"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="32"/>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="42"/>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="14"/>
        <source>Equalizer</source>
        <translation>Equalizador</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="39"/>
        <source>+12dB</source>
        <translation>+12dB</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="59"/>
        <source>-12dB</source>
        <translation>-12dB</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="219"/>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="263"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>FmtxSettingsDialog</name>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="14"/>
        <source>FMTX Settings</source>
        <translation>Configuracões FMTX</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="23"/>
        <source>Frequency:</source>
        <translation>Frequência:</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="39"/>
        <source>88</source>
        <translation>88</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="47"/>
        <source>89</source>
        <translation>89</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="55"/>
        <location filename="../ui/fmtxsettingsdialog.ui" line="353"/>
        <source>90</source>
        <translation>90</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="63"/>
        <source>91</source>
        <translation>91</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="71"/>
        <source>92</source>
        <translation>92</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="79"/>
        <source>93</source>
        <translation>93</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="87"/>
        <source>94</source>
        <translation>94</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="95"/>
        <location filename="../ui/fmtxsettingsdialog.ui" line="361"/>
        <source>95</source>
        <translation>95</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="103"/>
        <source>96</source>
        <translation>96</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="111"/>
        <source>97</source>
        <translation>97</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="119"/>
        <source>98</source>
        <translation>98</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="127"/>
        <source>99</source>
        <translation>99</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="135"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="143"/>
        <source>101</source>
        <translation>101</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="151"/>
        <source>102</source>
        <translation>102</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="159"/>
        <source>103</source>
        <translation>103</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="167"/>
        <source>104</source>
        <translation>104</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="175"/>
        <source>105</source>
        <translation>105</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="183"/>
        <source>106</source>
        <translation>106</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="191"/>
        <source>107</source>
        <translation>107</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="209"/>
        <source>00</source>
        <translation>00</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="217"/>
        <source>05</source>
        <translation>05</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="225"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="233"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="241"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="249"/>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="257"/>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="265"/>
        <source>35</source>
        <translation>35</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="273"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="281"/>
        <source>45</source>
        <translation>45</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="289"/>
        <source>50</source>
        <translation>50</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="297"/>
        <source>55</source>
        <translation>55</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="305"/>
        <source>60</source>
        <translation>60</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="313"/>
        <source>65</source>
        <translation>65</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="321"/>
        <source>70</source>
        <translation>70</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="329"/>
        <source>75</source>
        <translation>75</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="337"/>
        <source>80</source>
        <translation>80</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="345"/>
        <source>85</source>
        <translation>85</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="384"/>
        <source>Station:</source>
        <translation>Estação:</translation>
    </message>
</context>
<context>
    <name>LibraryForm</name>
    <message>
        <location filename="../ui/libraryform.ui" line="14"/>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <location filename="../ui/libraryform.ui" line="343"/>
        <location filename="../libraryform.cpp" line="174"/>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="201"/>
        <source>Dynamic playlists</source>
        <translation>Playlists dinâmicas</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="226"/>
        <location filename="../libraryform.cpp" line="417"/>
        <source>Albums by &quot;%1&quot;</source>
        <translation>Álbuns de &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="239"/>
        <source>Tracks from &quot;%1&quot; by &quot;%2&quot;</source>
        <translation>Faixas de &quot;%1&quot; por &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="249"/>
        <source>All tracks by &quot;%1&quot;</source>
        <translation>Todas as faixas de &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="267"/>
        <source>Tracks in playlist &quot;%1&quot;</source>
        <translation>Faixas na playlist &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="441"/>
        <source>Playlists</source>
        <translation>Playlists</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="886"/>
        <source>Search in library</source>
        <translation>Buscar na biblioteca</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>SomePlayer</source>
        <translation>SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="40"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="47"/>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="53"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="60"/>
        <source>Player</source>
        <translation>Tocador</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="68"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="80"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="85"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="90"/>
        <source>Manage library</source>
        <translation>Gerenciar biblioteca</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="95"/>
        <source>Equalizer</source>
        <translation>Equalizador</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="100"/>
        <source>Set timer</source>
        <translation>Definir temporizador</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="105"/>
        <source>Save playlist</source>
        <translation>Salvar playlist</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="108"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="113"/>
        <source>Online help</source>
        <translation>Ajuda online</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="118"/>
        <source>Import playlists</source>
        <translation>Importar playlists</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="123"/>
        <source>Add stream</source>
        <translation>Adicionar fluxo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Clear playlist?</source>
        <translation>Apagar playlist?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Music off: </source>
        <translation>Cortando a música em:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Select directory</source>
        <translation>Selecione o diretório</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Internet radio</source>
        <translation>Rádio na Internet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Audio stream</source>
        <translation>Stream de áudio</translation>
    </message>
</context>
<context>
    <name>ManageLibraryForm</name>
    <message>
        <location filename="../ui/managelibraryform.ui" line="14"/>
        <source>Manage library</source>
        <translation>Gerenciar biblioteca</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="231"/>
        <source>Added directories:</source>
        <translation>Diretórios adicionados:</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="295"/>
        <source>0 artitst</source>
        <translation>0 artistas</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="302"/>
        <source>0 albums</source>
        <translation>0 álbuns</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="312"/>
        <source>0 tracks</source>
        <translation>0 faixas</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="66"/>
        <source>Select directory</source>
        <translation>Selecione o diretório</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="126"/>
        <source>Delete selected directories?</source>
        <translation>Apagar os diretórios selecionados?</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="145"/>
        <source>Update selected directories? It may take several minutes</source>
        <translation>Atualizar os diretórios selecionados? Isto pode levar alguns minutos</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="165"/>
        <source>Update the entire library? It may take a long time</source>
        <translation>Atualizar toda a biblioteca? Isto pode levar bastante tempo</translation>
    </message>
</context>
<context>
    <name>PlayerForm</name>
    <message>
        <location filename="../ui/playerform.ui" line="14"/>
        <source>SomePlayer</source>
        <translation>SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="124"/>
        <source>Music off: 00:00:00</source>
        <translation>Cortando a música em: 00:00:00</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="472"/>
        <source>0/0</source>
        <translation>0/0</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="508"/>
        <source>&lt;h3&gt;Title&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Título&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="538"/>
        <location filename="../ui/playerform.ui" line="558"/>
        <source>00:00</source>
        <translation>00:00</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="634"/>
        <source>&lt;b&gt;Artist&lt;/b&gt;&lt;br/&gt;album</source>
        <translation>&lt;b&gt;Artista&lt;/b&gt;&lt;br/&gt;álbum</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="91"/>
        <location filename="../playerform.cpp" line="788"/>
        <source>Clear playlist</source>
        <translation>Apagar playlist</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="92"/>
        <location filename="../playerform.cpp" line="789"/>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="93"/>
        <location filename="../playerform.cpp" line="243"/>
        <location filename="../playerform.cpp" line="283"/>
        <location filename="../playerform.cpp" line="790"/>
        <source>Add to favorites</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="94"/>
        <location filename="../playerform.cpp" line="791"/>
        <source>Enqueue</source>
        <translation>Enfileirar</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="95"/>
        <location filename="../playerform.cpp" line="792"/>
        <source>Add to playlists</source>
        <translation>Adicionar a playlists</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="96"/>
        <location filename="../playerform.cpp" line="793"/>
        <source>Edit tags</source>
        <translation>Editar tags</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="243"/>
        <location filename="../playerform.cpp" line="283"/>
        <source>Remove from favorites</source>
        <translation>Remover dos favoritos</translation>
    </message>
</context>
<context>
    <name>PlaylistDialog</name>
    <message>
        <location filename="../ui/playlistdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>PlaylistSortForm</name>
    <message>
        <location filename="../ui/playlistsortform.ui" line="14"/>
        <source>Sorting</source>
        <translation>Ordenação</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libraryform.cpp" line="65"/>
        <source>All tracks</source>
        <translation>Todas as faixas</translation>
    </message>
</context>
<context>
    <name>SavePlaylistDialog</name>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="14"/>
        <source>Save playlist</source>
        <translation>Salvar playlist</translation>
    </message>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="26"/>
        <source>Existing playlists:</source>
        <translation>Playlists existentes:</translation>
    </message>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="39"/>
        <source>New: </source>
        <translation>Nova: </translation>
    </message>
</context>
<context>
    <name>SettingsForm</name>
    <message>
        <location filename="../ui/settingsform.ui" line="14"/>
        <location filename="../ui/settingsform.ui" line="695"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="28"/>
        <source>UI</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="41"/>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="54"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="106"/>
        <source>Icons theme:</source>
        <translation>Tema dos ícones:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="132"/>
        <location filename="../ui/settingsform.ui" line="238"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="139"/>
        <location filename="../ui/settingsform.ui" line="243"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="151"/>
        <source>Use gradient in portrait mode:</source>
        <translation>Usar gradientes no modo retrato:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="177"/>
        <location filename="../ui/settingsform.ui" line="509"/>
        <location filename="../ui/settingsform.ui" line="599"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="184"/>
        <location filename="../ui/settingsform.ui" line="516"/>
        <location filename="../ui/settingsform.ui" line="606"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="196"/>
        <source>Active track color:</source>
        <translation>Cor da faixa ativa:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="218"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="223"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="228"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="233"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="248"/>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="253"/>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="264"/>
        <source>Orientation:</source>
        <translation>Orientação:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="290"/>
        <source>Landscape</source>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="297"/>
        <source>Portrait</source>
        <translation>Retrato</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="304"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="316"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="438"/>
        <source>Sort album:</source>
        <translation>Ordenar álbum:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="464"/>
        <source>Alphabetical</source>
        <translation>Alfabeticamente</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="471"/>
        <source>By date</source>
        <translation>Por data</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="483"/>
        <source>Show track length in library view:</source>
        <translation>Mostrar duração das faixas na tela de visualização da biblioteca:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="579"/>
        <source>Pause when headphones unplugged:</source>
        <translation>Pausar quando o fone de ouvido for desconectado:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="618"/>
        <source>Use hardware keys</source>
        <translation>Utilizar teclas fisicas</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="639"/>
        <source>Zoom keys control:</source>
        <translation>Teclas de zoom controlam:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="648"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="655"/>
        <source>Tracks</source>
        <translation>Faixas</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="667"/>
        <source>Use FMTX</source>
        <translation>Uso do FMTX</translation>
    </message>
</context>
<context>
    <name>TimerDialog</name>
    <message>
        <location filename="../ui/timerdialog.ui" line="14"/>
        <source>Set timer</source>
        <translation>Definir temporizador</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="24"/>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="32"/>
        <location filename="../ui/timerdialog.ui" line="158"/>
        <location filename="../ui/timerdialog.ui" line="660"/>
        <source>00</source>
        <translation>00</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="40"/>
        <location filename="../ui/timerdialog.ui" line="166"/>
        <location filename="../ui/timerdialog.ui" line="668"/>
        <source>01</source>
        <translation>01</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="48"/>
        <location filename="../ui/timerdialog.ui" line="174"/>
        <location filename="../ui/timerdialog.ui" line="676"/>
        <source>02</source>
        <translation>02</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="56"/>
        <location filename="../ui/timerdialog.ui" line="182"/>
        <location filename="../ui/timerdialog.ui" line="684"/>
        <source>03</source>
        <translation>03</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="64"/>
        <location filename="../ui/timerdialog.ui" line="190"/>
        <location filename="../ui/timerdialog.ui" line="692"/>
        <source>04</source>
        <translation>04</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="72"/>
        <location filename="../ui/timerdialog.ui" line="198"/>
        <location filename="../ui/timerdialog.ui" line="700"/>
        <source>05</source>
        <translation>05</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="80"/>
        <location filename="../ui/timerdialog.ui" line="206"/>
        <location filename="../ui/timerdialog.ui" line="708"/>
        <source>06</source>
        <translation>06</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="88"/>
        <location filename="../ui/timerdialog.ui" line="214"/>
        <location filename="../ui/timerdialog.ui" line="716"/>
        <source>07</source>
        <translation>07</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="96"/>
        <location filename="../ui/timerdialog.ui" line="222"/>
        <location filename="../ui/timerdialog.ui" line="724"/>
        <source>08</source>
        <translation>08</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="104"/>
        <location filename="../ui/timerdialog.ui" line="230"/>
        <location filename="../ui/timerdialog.ui" line="732"/>
        <source>09</source>
        <translation>09</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="112"/>
        <location filename="../ui/timerdialog.ui" line="238"/>
        <location filename="../ui/timerdialog.ui" line="740"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="120"/>
        <location filename="../ui/timerdialog.ui" line="246"/>
        <location filename="../ui/timerdialog.ui" line="748"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="128"/>
        <location filename="../ui/timerdialog.ui" line="254"/>
        <location filename="../ui/timerdialog.ui" line="756"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="141"/>
        <location filename="../ui/timerdialog.ui" line="643"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="150"/>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="262"/>
        <location filename="../ui/timerdialog.ui" line="764"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="270"/>
        <location filename="../ui/timerdialog.ui" line="772"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="278"/>
        <location filename="../ui/timerdialog.ui" line="780"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="286"/>
        <location filename="../ui/timerdialog.ui" line="788"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="294"/>
        <location filename="../ui/timerdialog.ui" line="796"/>
        <source>17</source>
        <translation>17</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="302"/>
        <location filename="../ui/timerdialog.ui" line="804"/>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="310"/>
        <location filename="../ui/timerdialog.ui" line="812"/>
        <source>19</source>
        <translation>19</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="318"/>
        <location filename="../ui/timerdialog.ui" line="820"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="326"/>
        <location filename="../ui/timerdialog.ui" line="828"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="334"/>
        <location filename="../ui/timerdialog.ui" line="836"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="342"/>
        <location filename="../ui/timerdialog.ui" line="844"/>
        <source>23</source>
        <translation>23</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="350"/>
        <location filename="../ui/timerdialog.ui" line="852"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="358"/>
        <location filename="../ui/timerdialog.ui" line="860"/>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="366"/>
        <location filename="../ui/timerdialog.ui" line="868"/>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="374"/>
        <location filename="../ui/timerdialog.ui" line="876"/>
        <source>27</source>
        <translation>27</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="382"/>
        <location filename="../ui/timerdialog.ui" line="884"/>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="390"/>
        <location filename="../ui/timerdialog.ui" line="892"/>
        <source>29</source>
        <translation>29</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="398"/>
        <location filename="../ui/timerdialog.ui" line="900"/>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="406"/>
        <location filename="../ui/timerdialog.ui" line="908"/>
        <source>31</source>
        <translation>31</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="414"/>
        <location filename="../ui/timerdialog.ui" line="916"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="422"/>
        <location filename="../ui/timerdialog.ui" line="924"/>
        <source>33</source>
        <translation>33</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="430"/>
        <location filename="../ui/timerdialog.ui" line="932"/>
        <source>34</source>
        <translation>34</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="438"/>
        <location filename="../ui/timerdialog.ui" line="940"/>
        <source>35</source>
        <translation>35</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="446"/>
        <location filename="../ui/timerdialog.ui" line="948"/>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="454"/>
        <location filename="../ui/timerdialog.ui" line="956"/>
        <source>37</source>
        <translation>37</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="462"/>
        <location filename="../ui/timerdialog.ui" line="964"/>
        <source>38</source>
        <translation>38</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="470"/>
        <location filename="../ui/timerdialog.ui" line="972"/>
        <source>39</source>
        <translation>39</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="478"/>
        <location filename="../ui/timerdialog.ui" line="980"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="486"/>
        <location filename="../ui/timerdialog.ui" line="988"/>
        <source>41</source>
        <translation>41</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="494"/>
        <location filename="../ui/timerdialog.ui" line="996"/>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="502"/>
        <location filename="../ui/timerdialog.ui" line="1004"/>
        <source>43</source>
        <translation>43</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="510"/>
        <location filename="../ui/timerdialog.ui" line="1012"/>
        <source>44</source>
        <translation>44</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="518"/>
        <location filename="../ui/timerdialog.ui" line="1020"/>
        <source>45</source>
        <translation>45</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="526"/>
        <location filename="../ui/timerdialog.ui" line="1028"/>
        <source>46</source>
        <translation>46</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="534"/>
        <location filename="../ui/timerdialog.ui" line="1036"/>
        <source>47</source>
        <translation>47</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="542"/>
        <location filename="../ui/timerdialog.ui" line="1044"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="550"/>
        <location filename="../ui/timerdialog.ui" line="1052"/>
        <source>49</source>
        <translation>49</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="558"/>
        <location filename="../ui/timerdialog.ui" line="1060"/>
        <source>50</source>
        <translation>50</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="566"/>
        <location filename="../ui/timerdialog.ui" line="1068"/>
        <source>51</source>
        <translation>51</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="574"/>
        <location filename="../ui/timerdialog.ui" line="1076"/>
        <source>52</source>
        <translation>52</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="582"/>
        <location filename="../ui/timerdialog.ui" line="1084"/>
        <source>53</source>
        <translation>53</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="590"/>
        <location filename="../ui/timerdialog.ui" line="1092"/>
        <source>54</source>
        <translation>54</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="598"/>
        <location filename="../ui/timerdialog.ui" line="1100"/>
        <source>55</source>
        <translation>55</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="606"/>
        <location filename="../ui/timerdialog.ui" line="1108"/>
        <source>56</source>
        <translation>56</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="614"/>
        <location filename="../ui/timerdialog.ui" line="1116"/>
        <source>57</source>
        <translation>57</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="622"/>
        <location filename="../ui/timerdialog.ui" line="1124"/>
        <source>58</source>
        <translation>58</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="630"/>
        <location filename="../ui/timerdialog.ui" line="1132"/>
        <source>59</source>
        <translation>59</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="652"/>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="1153"/>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
</context>
<context>
    <name>ToolsWidget</name>
    <message>
        <location filename="../ui/toolswidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
</context>
</TS>
